@@ -7,6 +7,7 @@ install_aliases()
 from jinja2 import Environment, PackageLoader
 
 import json, uuid
+import re
 import datetime
 import html
 from collections import Iterable
@@ -60,10 +61,10 @@ class Highstock(object):
         
         # set Javascript src, Highcharts lib needs to make sure it's up to date
         self.JSsource = [
-                'https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js',
-                'https://code.highcharts.com/stock/highstock.js',
-                'https://code.highcharts.com/stock/modules/exporting.js',
-                'https://code.highcharts.com/highcharts-more.js',
+                'https://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js',
+                'https://code.highcharts.com/stock/6/highstock.js',
+                'https://code.highcharts.com/stock/6/modules/exporting.js',
+                'https://code.highcharts.com/6/highcharts-more.js',
             ]
 
         # set CSS src
@@ -82,6 +83,7 @@ class Highstock(object):
 
         # Data from jsonp
         self.jsonp_data_flag = False
+        self.jsonp_data_url_list = [] # DEM 2017/04/25: List of JSON data sources
         
         # javascript
         self.jscript_head_flag = False
@@ -205,13 +207,15 @@ class Highstock(object):
         """
         if not self.jsonp_data_flag:
             self.jsonp_data_flag = True
-            self.jsonp_data_url = json.dumps(data_src) 
             
             if data_name == 'data':
                 data_name = 'json_'+ data_name
             
             self.jsonp_data = data_name
         self.add_data_set(RawJavaScriptText(self.jsonp_data), series_type, name=name, **kwargs)
+        # DEM 2017/04/25: Append new JSON data source to a list instead of
+        #                 replacing whatever already exists
+        self.jsonp_data_url_list.append(json.dumps(data_src))
 
 
     def add_navi_series(self, data, series_type="line", **kwargs):
@@ -269,6 +273,8 @@ class Highstock(object):
                 self.options[option_type].update(**each_dict)
         elif option_type == 'colors':
             self.options["colors"].set_colors(option_dict) # option_dict should be a list
+        elif option_type in ["global" , "lang"]: #Highcharts.setOptions: 
+            self.setOptions[option_type].update_dict(**option_dict)
         else:
             self.options[option_type].update_dict(**option_dict)
 
@@ -291,6 +297,11 @@ class Highstock(object):
         self.option = json.dumps(self.options, cls = HighchartsEncoder)
         self.setoption = json.dumps(self.setOptions, cls = HighchartsEncoder) 
         self.data = json.dumps(self.data_temp, cls = HighchartsEncoder)
+
+        # DEM 2017/04/25: Make 'data' available as an array
+        # ... this permits jinja2 array access to each data definition
+        # ... which is useful for looping over multiple data sources
+        self.data_list = [json.dumps(x, cls = HighchartsEncoder) for x in self.data_temp]
         
         if self.navi_seri_flag:        
             self.navi_seri = json.dumps(self.navi_seri_temp, cls = HighchartsEncoder)
@@ -355,17 +366,19 @@ class Highstock(object):
     @property
     def iframe(self):
         htmlsrcdoc = html.escape(self.htmlcontent)
+        htmlsrcdoc = re.sub('\\n', ' ', htmlsrcdoc)
+        htmlsrcdoc = re.sub(' +', ' ', htmlsrcdoc)
         width = int(self.options['chart'].__dict__['width']) if self.options['chart'].__dict__.get('width') else 820
         height = int(self.options['chart'].__dict__['height']) if self.options['chart'].__dict__.get('height') else 520
         
         if self.options['chart'].__dict__.get('options3d'):
             if len(htmlsrcdoc) < 99965000 :
-                return '<iframe style="border:0;outline:none;overflow:hidden" src="data:text/html,'+ htmlsrcdoc + ' "height= ' + str(height) +' \
-                        width =' + str(width) + '></iframe>'
+                return '<iframe style="border:0;outline:none;overflow:hidden" src="data:text/html,'+ htmlsrcdoc + '" height=' + str(height) + \
+                        ' width=' + str(width) + '></iframe>'
             else:
-                return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + ' "height= '+ str(height) + ' width = ' + str(width) + '></iframe>'
+                return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + '" height='+ str(height) + ' width=' + str(width) + '></iframe>'
         else:
-            return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + ' "height= '+ str(height) + ' width = ' + str(width) + '></iframe>'
+            return '<iframe style="border:0;outline:none;overflow:hidden" srcdoc="'+ htmlsrcdoc + '" height='+ str(height) + ' width=' + str(width) + '></iframe>'
 
     def __str__(self):
         """return htmlcontent"""
